Module actor

Module actor 

Traits and type definitions for actors.

This module defines the Actor trait and its ActorContext companion, which together describe how an actor is started, processes messages, and shuts down.

Structs

ActorId
Actor index.
JoinHandle
An owned permission to join on a task (await its termination).

Enums

ActorState
State of an actor.
Stopping
Return value of Actor::stopping.

Traits

Actor
An actor.
ActorContext
The execution context of an actor.
RemoteAddressableipc
An actor which can be reached from other processes.
RemoteSpawnableipc
An actor type which can be created from another process.