Module address

Module address 

Traits and type definitions for actor address.

In the actor model, an Address is a handle to an actor. It is the only way to interact with an actor since the runtime will take the ownership of the actor itself after it is spawned.

This module defines the Address type for an actor. It also provides the Sender trait and a Recipient type which are alternative ways to organize the addresses of actors.

Structs

Address
The address of an actor.
Mailbox
The mailbox of an actor, which holds a queue of messages to be processed by the actor.
OwnedSendPermit
Owned permit to send one message to an actor.
Recipient
A type which is used to send a specific message type to an actor.
SendPermit
Permit to send one message to an actor.

Traits

Sender
Describes how to send a message.
SenderId
Describes how to retrieve the index of a sender.

Type Aliases

ClosedResultFuture
DoSendResult
DoSendResultFuture
SendResult
SendResultFuture