RemoteMailbox

Type Alias RemoteMailbox 

pub type RemoteMailbox = Recipient<BinaryMessage>;
Available on crate feature ipc only.
A remote mailbox which can be used by the runtime to deliver binary messages to a remote addressable actor.

It is an alias of the address of the actor in the form of a Recipient<BinaryMessage>.

Aliased Type

pub struct RemoteMailbox(/* private fields */);