Signal

Enum Signal 

#[repr(u8)]
pub enum Signal { Stop = 0, Terminate = 1, }
A message which is used to stop/terminate an actor.

Handler<Signal> is implemented for all actors automatically.

Variants



Stop = 0

Stop the actor.

Set the actor’s state to Stopping and trigger the stopping method of the actor. The actor might be able to resume by itself.



Terminate = 1

Terminate the actor.

Set the actor’s state to Stopped and trigger the post_stop method. Any messages still queued in the mailbox behind this signal are dropped without being handled.