Module observer

Module observer 

Observer pattern for actors.

This module provides a way to implement the observer pattern for actors.

Macros

notify_observers
Notifies all observers with the given event asynchronously, cleaning up closed observers.
try_notify_observers
Tries to notify all observers with the given event, cleaning up closed observers.

Structs

ObserverSet
Container for observers.

Enums

Observer
A message which is used to register/unregister an observer.

Traits

SubjectActor
Describes the behavior of an actor which works as a subject of the given event type.