pub struct MessageResult<M>(pub M::Result)
where
M: Message;Expand description
A helper type which wraps the result of a message handler as a message response.
This is useful when the result type of a message does not implement MessageResponse, and
you can not implement MessageResponse for the type due to the orphan rule. In this case,
you can wrap the result type with this type and use it as the
Handler::Result associate type.
Tuple Fields
0: M::ResultTrait Implementations
Sourceimpl<M> Debug for MessageResult<M>where
M: Message,
impl<M> Debug for MessageResult<M>where
M: Message,