Supervision for actors.
This module provides a way to watch the status of an actor.
Enums
- Supervision
Event - A message which is used to report actor status to a supervisor.
- Supervisor
- A message which is used to set/unset a supervisor.